==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Vyčistit záznam událostí (log)</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Opravdu chcete záznam událostí vyčistit?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dny</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 týden</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 měsíc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 měsíce</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Export</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nouzové</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Výstraha</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritické</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Ladění</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Přihlášení</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Start systému</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypínání</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritické</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; XLS (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportování…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Export úspěšný</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export se nezdařil</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportovat soubor</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Období:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Úroveň podrobností:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Seznam aplikací:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ události:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uživatel:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>Identif. procesu:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akce:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Záznam události ze startu systému</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Záznam událostí z vypínání</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Záznam událostí z přihlašování</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Ladění</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nouzové</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Výstraha</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritický</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritické</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Soubor se záznamem událostí je prázdný</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Prohlížeč záznamů událostí</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Prohlížeč záznamů událostí je užitečným nástrojem pro prohlížení záznamů událostí v systému.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Úroveň podrobností</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum a čas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>Identif. procesu (PID):</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ události</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum a čas:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informace:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Prázdné</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uživatel:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>Identif. procesu (PID):</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum a čas</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Záznam událostí v systému</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Události v jádru systému</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Záznam událostí ze startu systému</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Události v systému správy balíčků</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Záznam událostí v Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Události v infrastruktuře pro zobrazování (Xorg)</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Záznam událostí v aplikacích</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Událost při startu/vypínání systému</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>záznam událostí v dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Vyčistit záznam událostí (log)</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Načíst znovu</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Opravdu chcete záznam událostí vyčistit?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dny</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 týden</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 měsíc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 měsíce</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nouzové</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Výstraha</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritické</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Ladění</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Přihlášení</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Start systému</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Vypínání</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritické</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Ověření identity</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Rozvahové/posudkové řízení přístupu</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Mandatorní řízení přístupu</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Vzdálené</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Audit dokumentu</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; XLS (*.xls);; HTML (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Exportování…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Export úspěšný</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Export se nezdařil</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportovat soubor</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Období:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Úroveň podrobností:  </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ události:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uživatel:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>Identif. procesu:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akce:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Záznam události ze startu systému</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Záznam událostí z vypínání</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Záznam událostí z přihlašování</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Typ auditu:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Ladění</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Nouzové</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Výstraha</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritická</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Trace</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super kritické</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Soubor se záznamem událostí je prázdný</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Prohlížeč záznamů událostí</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Prohlížeč záznamů událostí je užitečným nástrojem pro prohlížení záznamů událostí v systému.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nic nenalezeno</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Úroveň podrobností</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum a čas</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Pro informaci</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>Identif. procesu (PID):</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akce</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ události</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Úroveň:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum a čas:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informace:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Prázdné</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Uživatel:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>Identif. procesu (PID):</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Okamžik změny</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum a čas</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Záznam událostí v systému</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Události v jádru systému</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Záznam událostí ze startu systému</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Události v systému správy balíčků</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Záznam událostí v Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Události v infrastruktuře pro zobrazování (Xorg)</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Záznam událostí v aplikacích</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Událost při startu/vypínání systému</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>záznam událostí v dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Jiný záznam</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Uživatelsky určený záznam událostí</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Auditní log</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Nemáte oprávnění k zobrazení</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval opakovaného načítání</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sekund</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 minuta</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 minut</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nedonačítat</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exportovat vše</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Načíst znovu nyní</translation>
    </message>
</context>
</TS>
